@@ -160,7 +160,7 @@ GType  bd_btrfs_filesystem_info_get_type () {
     return type;
 }
 
-static gboolean  bd_btrfs_is_tech_avail_stub (BDBtrfsTech tech, guint64 mode, GError **error) {
+static gboolean  bd_btrfs_is_tech_avail_stub (BDBtrfsTech tech G_GNUC_UNUSED, guint64 mode G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_is_tech_avail' called, but not implemented!");
@@ -183,7 +183,7 @@ gboolean  bd_btrfs_is_tech_avail (BDBtrfsTech tech, guint64 mode, GError **error
 }
 
 
-static gboolean  bd_btrfs_create_volume_stub (const gchar **devices, const gchar *label, const gchar *data_level, const gchar *md_level, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_create_volume_stub (const gchar **devices G_GNUC_UNUSED, const gchar *label G_GNUC_UNUSED, const gchar *data_level G_GNUC_UNUSED, const gchar *md_level G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_create_volume' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_create_volume' called, but not implemented!");
@@ -213,7 +213,7 @@ gboolean  bd_btrfs_create_volume (const gchar **devices, const gchar *label, con
 }
 
 
-static gboolean  bd_btrfs_add_device_stub (const gchar *mountpoint, const gchar *device, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_add_device_stub (const gchar *mountpoint G_GNUC_UNUSED, const gchar *device G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_add_device' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_add_device' called, but not implemented!");
@@ -239,7 +239,7 @@ gboolean  bd_btrfs_add_device (const gchar *mountpoint, const gchar *device, con
 }
 
 
-static gboolean  bd_btrfs_remove_device_stub (const gchar *mountpoint, const gchar *device, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_remove_device_stub (const gchar *mountpoint G_GNUC_UNUSED, const gchar *device G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_remove_device' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_remove_device' called, but not implemented!");
@@ -265,7 +265,7 @@ gboolean  bd_btrfs_remove_device (const gchar *mountpoint, const gchar *device,
 }
 
 
-static gboolean  bd_btrfs_create_subvolume_stub (const gchar *mountpoint, const gchar *name, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_create_subvolume_stub (const gchar *mountpoint G_GNUC_UNUSED, const gchar *name G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_create_subvolume' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_create_subvolume' called, but not implemented!");
@@ -291,7 +291,7 @@ gboolean  bd_btrfs_create_subvolume (const gchar *mountpoint, const gchar *name,
 }
 
 
-static gboolean  bd_btrfs_delete_subvolume_stub (const gchar *mountpoint, const gchar *name, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_delete_subvolume_stub (const gchar *mountpoint G_GNUC_UNUSED, const gchar *name G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_delete_subvolume' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_delete_subvolume' called, but not implemented!");
@@ -317,7 +317,7 @@ gboolean  bd_btrfs_delete_subvolume (const gchar *mountpoint, const gchar *name,
 }
 
 
-static guint64  bd_btrfs_get_default_subvolume_id_stub (const gchar *mountpoint, GError **error) {
+static guint64  bd_btrfs_get_default_subvolume_id_stub (const gchar *mountpoint G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_get_default_subvolume_id' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_get_default_subvolume_id' called, but not implemented!");
@@ -341,7 +341,7 @@ guint64  bd_btrfs_get_default_subvolume_id (const gchar *mountpoint, GError **er
 }
 
 
-static gboolean  bd_btrfs_set_default_subvolume_stub (const gchar *mountpoint, guint64 subvol_id, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_set_default_subvolume_stub (const gchar *mountpoint G_GNUC_UNUSED, guint64 subvol_id G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_set_default_subvolume' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_set_default_subvolume' called, but not implemented!");
@@ -368,7 +368,7 @@ gboolean  bd_btrfs_set_default_subvolume (const gchar *mountpoint, guint64 subvo
 }
 
 
-static gboolean  bd_btrfs_create_snapshot_stub (const gchar *source, const gchar *dest, gboolean ro, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_create_snapshot_stub (const gchar *source G_GNUC_UNUSED, const gchar *dest G_GNUC_UNUSED, gboolean ro G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_create_snapshot' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_create_snapshot' called, but not implemented!");
@@ -395,7 +395,7 @@ gboolean  bd_btrfs_create_snapshot (const gchar *source, const gchar *dest, gboo
 }
 
 
-static BDBtrfsDeviceInfo** bd_btrfs_list_devices_stub (const gchar *device, GError **error) {
+static BDBtrfsDeviceInfo** bd_btrfs_list_devices_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_list_devices' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_list_devices' called, but not implemented!");
@@ -419,7 +419,7 @@ BDBtrfsDeviceInfo** bd_btrfs_list_devices (const gchar *device, GError **error)
 }
 
 
-static BDBtrfsSubvolumeInfo** bd_btrfs_list_subvolumes_stub (const gchar *mountpoint, gboolean snapshots_only, GError **error) {
+static BDBtrfsSubvolumeInfo** bd_btrfs_list_subvolumes_stub (const gchar *mountpoint G_GNUC_UNUSED, gboolean snapshots_only G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_list_subvolumes' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_list_subvolumes' called, but not implemented!");
@@ -447,7 +447,7 @@ BDBtrfsSubvolumeInfo** bd_btrfs_list_subvolumes (const gchar *mountpoint, gboole
 }
 
 
-static BDBtrfsFilesystemInfo* bd_btrfs_filesystem_info_stub (const gchar *device, GError **error) {
+static BDBtrfsFilesystemInfo* bd_btrfs_filesystem_info_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_filesystem_info' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_filesystem_info' called, but not implemented!");
@@ -470,7 +470,7 @@ BDBtrfsFilesystemInfo* bd_btrfs_filesystem_info (const gchar *device, GError **e
 }
 
 
-static gboolean  bd_btrfs_mkfs_stub (const gchar **devices, const gchar *label, const gchar *data_level, const gchar *md_level, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_mkfs_stub (const gchar **devices G_GNUC_UNUSED, const gchar *label G_GNUC_UNUSED, const gchar *data_level G_GNUC_UNUSED, const gchar *md_level G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_mkfs' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_mkfs' called, but not implemented!");
@@ -500,7 +500,7 @@ gboolean  bd_btrfs_mkfs (const gchar **devices, const gchar *label, const gchar
 }
 
 
-static gboolean  bd_btrfs_resize_stub (const gchar *mountpoint, guint64 size, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_resize_stub (const gchar *mountpoint G_GNUC_UNUSED, guint64 size G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_resize' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_resize' called, but not implemented!");
@@ -527,7 +527,7 @@ gboolean  bd_btrfs_resize (const gchar *mountpoint, guint64 size, const BDExtraA
 }
 
 
-static gboolean  bd_btrfs_check_stub (const gchar *device, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_check_stub (const gchar *device G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_check' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_check' called, but not implemented!");
@@ -552,7 +552,7 @@ gboolean  bd_btrfs_check (const gchar *device, const BDExtraArg **extra, GError
 }
 
 
-static gboolean  bd_btrfs_repair_stub (const gchar *device, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_repair_stub (const gchar *device G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_repair' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_repair' called, but not implemented!");
@@ -577,7 +577,7 @@ gboolean  bd_btrfs_repair (const gchar *device, const BDExtraArg **extra, GError
 }
 
 
-static gboolean  bd_btrfs_change_label_stub (const gchar *mountpoint, const gchar *label, GError **error) {
+static gboolean  bd_btrfs_change_label_stub (const gchar *mountpoint G_GNUC_UNUSED, const gchar *label G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_btrfs_change_label' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_change_label' called, but not implemented!");
