@@ -2,7 +2,7 @@ GQuark  bd_dm_error_quark (void) {
         return g_quark_from_static_string ("g-bd-dm-error-quark");
 }
 
-static gboolean  bd_dm_is_tech_avail_stub (BDDMTech tech, guint64 mode, GError **error) {
+static gboolean  bd_dm_is_tech_avail_stub (BDDMTech tech G_GNUC_UNUSED, guint64 mode G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_dm_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_is_tech_avail' called, but not implemented!");
@@ -25,7 +25,7 @@ gboolean  bd_dm_is_tech_avail (BDDMTech tech, guint64 mode, GError **error) {
 }
 
 
-static gboolean  bd_dm_create_linear_stub (const gchar *map_name, const gchar *device, guint64 length, const gchar *uuid, GError **error) {
+static gboolean  bd_dm_create_linear_stub (const gchar *map_name G_GNUC_UNUSED, const gchar *device G_GNUC_UNUSED, guint64 length G_GNUC_UNUSED, const gchar *uuid G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_dm_create_linear' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_create_linear' called, but not implemented!");
@@ -52,7 +52,7 @@ gboolean  bd_dm_create_linear (const gchar *map_name, const gchar *device, guint
 }
 
 
-static gboolean  bd_dm_remove_stub (const gchar *map_name, GError **error) {
+static gboolean  bd_dm_remove_stub (const gchar *map_name G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_dm_remove' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_remove' called, but not implemented!");
@@ -75,7 +75,7 @@ gboolean  bd_dm_remove (const gchar *map_name, GError **error) {
 }
 
 
-static gchar* bd_dm_name_from_node_stub (const gchar *dm_node, GError **error) {
+static gchar* bd_dm_name_from_node_stub (const gchar *dm_node G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_dm_name_from_node' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_name_from_node' called, but not implemented!");
@@ -99,7 +99,7 @@ gchar* bd_dm_name_from_node (const gchar *dm_node, GError **error) {
 }
 
 
-static gchar* bd_dm_node_from_name_stub (const gchar *map_name, GError **error) {
+static gchar* bd_dm_node_from_name_stub (const gchar *map_name G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_dm_node_from_name' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_node_from_name' called, but not implemented!");
@@ -123,7 +123,7 @@ gchar* bd_dm_node_from_name (const gchar *map_name, GError **error) {
 }
 
 
-static gchar* bd_dm_get_subsystem_from_name_stub (const gchar *device_name, GError **error) {
+static gchar* bd_dm_get_subsystem_from_name_stub (const gchar *device_name G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_dm_get_subsystem_from_name' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_get_subsystem_from_name' called, but not implemented!");
@@ -146,7 +146,7 @@ gchar* bd_dm_get_subsystem_from_name (const gchar *device_name, GError **error)
 }
 
 
-static gboolean  bd_dm_map_exists_stub (const gchar *map_name, gboolean live_only, gboolean active_only, GError **error) {
+static gboolean  bd_dm_map_exists_stub (const gchar *map_name G_GNUC_UNUSED, gboolean live_only G_GNUC_UNUSED, gboolean active_only G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_dm_map_exists' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_map_exists' called, but not implemented!");
