@@ -156,7 +156,7 @@ GType  bd_md_detail_data_get_type () {
     return type;
 }
 
-static gboolean  bd_md_is_tech_avail_stub (BDMDTech tech, guint64 mode, GError **error) {
+static gboolean  bd_md_is_tech_avail_stub (BDMDTech tech G_GNUC_UNUSED, guint64 mode G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_is_tech_avail' called, but not implemented!");
@@ -179,7 +179,7 @@ gboolean  bd_md_is_tech_avail (BDMDTech tech, guint64 mode, GError **error) {
 }
 
 
-static guint64  bd_md_get_superblock_size_stub (guint64 member_size, const gchar *version, GError **error) {
+static guint64  bd_md_get_superblock_size_stub (guint64 member_size G_GNUC_UNUSED, const gchar *version G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_get_superblock_size' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_get_superblock_size' called, but not implemented!");
@@ -204,7 +204,7 @@ guint64  bd_md_get_superblock_size (guint64 member_size, const gchar *version, G
 }
 
 
-static gboolean  bd_md_create_stub (const gchar *device_name, const gchar *level, const gchar **disks, guint64 spares, const gchar *version, const gchar *bitmap, guint64 chunk_size, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_md_create_stub (const gchar *device_name G_GNUC_UNUSED, const gchar *level G_GNUC_UNUSED, const gchar **disks G_GNUC_UNUSED, guint64 spares G_GNUC_UNUSED, const gchar *version G_GNUC_UNUSED, const gchar *bitmap G_GNUC_UNUSED, guint64 chunk_size G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_create' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_create' called, but not implemented!");
@@ -235,7 +235,7 @@ gboolean  bd_md_create (const gchar *device_name, const gchar *level, const gcha
 }
 
 
-static gboolean  bd_md_destroy_stub (const gchar *device, GError **error) {
+static gboolean  bd_md_destroy_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_destroy' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_destroy' called, but not implemented!");
@@ -258,7 +258,7 @@ gboolean  bd_md_destroy (const gchar *device, GError **error) {
 }
 
 
-static gboolean  bd_md_deactivate_stub (const gchar *raid_spec, GError **error) {
+static gboolean  bd_md_deactivate_stub (const gchar *raid_spec G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_deactivate' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_deactivate' called, but not implemented!");
@@ -281,7 +281,7 @@ gboolean  bd_md_deactivate (const gchar *raid_spec, GError **error) {
 }
 
 
-static gboolean  bd_md_activate_stub (const gchar *raid_spec, const gchar **members, const gchar *uuid, gboolean start_degraded, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_md_activate_stub (const gchar *raid_spec G_GNUC_UNUSED, const gchar **members G_GNUC_UNUSED, const gchar *uuid G_GNUC_UNUSED, gboolean start_degraded G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_activate' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_activate' called, but not implemented!");
@@ -311,7 +311,7 @@ gboolean  bd_md_activate (const gchar *raid_spec, const gchar **members, const g
 }
 
 
-static gboolean  bd_md_run_stub (const gchar *raid_spec, GError **error) {
+static gboolean  bd_md_run_stub (const gchar *raid_spec G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_run' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_run' called, but not implemented!");
@@ -334,7 +334,7 @@ gboolean  bd_md_run (const gchar *raid_spec, GError **error) {
 }
 
 
-static gboolean  bd_md_nominate_stub (const gchar *device, GError **error) {
+static gboolean  bd_md_nominate_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_nominate' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_nominate' called, but not implemented!");
@@ -360,7 +360,7 @@ gboolean  bd_md_nominate (const gchar *device, GError **error) {
 }
 
 
-static gboolean  bd_md_denominate_stub (const gchar *device, GError **error) {
+static gboolean  bd_md_denominate_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_denominate' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_denominate' called, but not implemented!");
@@ -386,7 +386,7 @@ gboolean  bd_md_denominate (const gchar *device, GError **error) {
 }
 
 
-static gboolean  bd_md_add_stub (const gchar *raid_spec, const gchar *device, guint64 raid_devs, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_md_add_stub (const gchar *raid_spec G_GNUC_UNUSED, const gchar *device G_GNUC_UNUSED, guint64 raid_devs G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_add' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_add' called, but not implemented!");
@@ -422,7 +422,7 @@ gboolean  bd_md_add (const gchar *raid_spec, const gchar *device, guint64 raid_d
 }
 
 
-static gboolean  bd_md_remove_stub (const gchar *raid_spec, const gchar *device, gboolean fail, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_md_remove_stub (const gchar *raid_spec G_GNUC_UNUSED, const gchar *device G_GNUC_UNUSED, gboolean fail G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_remove' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_remove' called, but not implemented!");
@@ -450,7 +450,7 @@ gboolean  bd_md_remove (const gchar *raid_spec, const gchar *device, gboolean fa
 }
 
 
-static BDMDExamineData* bd_md_examine_stub (const gchar *device, GError **error) {
+static BDMDExamineData* bd_md_examine_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_examine' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_examine' called, but not implemented!");
@@ -473,7 +473,7 @@ BDMDExamineData* bd_md_examine (const gchar *device, GError **error) {
 }
 
 
-static BDMDDetailData* bd_md_detail_stub (const gchar *raid_spec, GError **error) {
+static BDMDDetailData* bd_md_detail_stub (const gchar *raid_spec G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_detail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_detail' called, but not implemented!");
@@ -496,7 +496,7 @@ BDMDDetailData* bd_md_detail (const gchar *raid_spec, GError **error) {
 }
 
 
-static gchar* bd_md_canonicalize_uuid_stub (const gchar *uuid, GError **error) {
+static gchar* bd_md_canonicalize_uuid_stub (const gchar *uuid G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_canonicalize_uuid' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_canonicalize_uuid' called, but not implemented!");
@@ -522,7 +522,7 @@ gchar* bd_md_canonicalize_uuid (const gchar *uuid, GError **error) {
 }
 
 
-static gchar* bd_md_get_md_uuid_stub (const gchar *uuid, GError **error) {
+static gchar* bd_md_get_md_uuid_stub (const gchar *uuid G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_get_md_uuid' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_get_md_uuid' called, but not implemented!");
@@ -550,7 +550,7 @@ gchar* bd_md_get_md_uuid (const gchar *uuid, GError **error) {
 }
 
 
-static gchar* bd_md_node_from_name_stub (const gchar *name, GError **error) {
+static gchar* bd_md_node_from_name_stub (const gchar *name G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_node_from_name' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_node_from_name' called, but not implemented!");
@@ -573,7 +573,7 @@ gchar* bd_md_node_from_name (const gchar *name, GError **error) {
 }
 
 
-static gchar* bd_md_name_from_node_stub (const gchar *node, GError **error) {
+static gchar* bd_md_name_from_node_stub (const gchar *node G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_name_from_node' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_name_from_node' called, but not implemented!");
@@ -596,7 +596,7 @@ gchar* bd_md_name_from_node (const gchar *node, GError **error) {
 }
 
 
-static gchar* bd_md_get_status_stub (const gchar *raid_spec, GError **error) {
+static gchar* bd_md_get_status_stub (const gchar *raid_spec G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_get_status' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_get_status' called, but not implemented!");
@@ -619,7 +619,7 @@ gchar* bd_md_get_status (const gchar *raid_spec, GError **error) {
 }
 
 
-static gboolean  bd_md_set_bitmap_location_stub (const gchar *raid_spec, const gchar *location, GError **error) {
+static gboolean  bd_md_set_bitmap_location_stub (const gchar *raid_spec G_GNUC_UNUSED, const gchar *location G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_set_bitmap_location' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_set_bitmap_location' called, but not implemented!");
@@ -643,7 +643,7 @@ gboolean  bd_md_set_bitmap_location (const gchar *raid_spec, const gchar *locati
 }
 
 
-static gchar* bd_md_get_bitmap_location_stub (const gchar *raid_spec, GError **error) {
+static gchar* bd_md_get_bitmap_location_stub (const gchar *raid_spec G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_get_bitmap_location' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_get_bitmap_location' called, but not implemented!");
@@ -666,7 +666,7 @@ gchar* bd_md_get_bitmap_location (const gchar *raid_spec, GError **error) {
 }
 
 
-static gboolean  bd_md_request_sync_action_stub (const gchar *raid_spec, const gchar *action, GError **error) {
+static gboolean  bd_md_request_sync_action_stub (const gchar *raid_spec G_GNUC_UNUSED, const gchar *action G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_md_request_sync_action' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_request_sync_action' called, but not implemented!");
