@@ -2,7 +2,7 @@ GQuark  bd_mpath_error_quark (void) {
         return g_quark_from_static_string ("g-bd-mpath-error-quark");
 }
 
-static gboolean  bd_mpath_is_tech_avail_stub (BDMpathTech tech, guint64 mode, GError **error) {
+static gboolean  bd_mpath_is_tech_avail_stub (BDMpathTech tech G_GNUC_UNUSED, guint64 mode G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_mpath_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_mpath_is_tech_avail' called, but not implemented!");
@@ -49,7 +49,7 @@ gboolean  bd_mpath_flush_mpaths (GError **error) {
 }
 
 
-static gboolean  bd_mpath_is_mpath_member_stub (const gchar *device, GError **error) {
+static gboolean  bd_mpath_is_mpath_member_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_mpath_is_mpath_member' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_mpath_is_mpath_member' called, but not implemented!");
@@ -97,7 +97,7 @@ gchar** bd_mpath_get_mpath_members (GError **error) {
 }
 
 
-static gboolean  bd_mpath_set_friendly_names_stub (gboolean enabled, GError **error) {
+static gboolean  bd_mpath_set_friendly_names_stub (gboolean enabled G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_mpath_set_friendly_names' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_mpath_set_friendly_names' called, but not implemented!");
