@@ -63,7 +63,7 @@ GType  bd_nvdimm_namespace_info_get_type () {
     return type;
 }
 
-static gboolean  bd_nvdimm_is_tech_avail_stub (BDNVDIMMTech tech, guint64 mode, GError **error) {
+static gboolean  bd_nvdimm_is_tech_avail_stub (BDNVDIMMTech tech G_GNUC_UNUSED, guint64 mode G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_nvdimm_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_is_tech_avail' called, but not implemented!");
@@ -86,7 +86,7 @@ gboolean  bd_nvdimm_is_tech_avail (BDNVDIMMTech tech, guint64 mode, GError **err
 }
 
 
-static BDNVDIMMNamespaceMode  bd_nvdimm_namespace_get_mode_from_str_stub (const gchar *mode_str, GError **error) {
+static BDNVDIMMNamespaceMode  bd_nvdimm_namespace_get_mode_from_str_stub (const gchar *mode_str G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_nvdimm_namespace_get_mode_from_str' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_get_mode_from_str' called, but not implemented!");
@@ -109,7 +109,7 @@ BDNVDIMMNamespaceMode  bd_nvdimm_namespace_get_mode_from_str (const gchar *mode_
 }
 
 
-static const gchar* bd_nvdimm_namespace_get_mode_str_stub (BDNVDIMMNamespaceMode mode, GError **error) {
+static const gchar* bd_nvdimm_namespace_get_mode_str_stub (BDNVDIMMNamespaceMode mode G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_nvdimm_namespace_get_mode_str' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_get_mode_str' called, but not implemented!");
@@ -132,7 +132,7 @@ const gchar* bd_nvdimm_namespace_get_mode_str (BDNVDIMMNamespaceMode mode, GErro
 }
 
 
-static gchar* bd_nvdimm_namespace_get_devname_stub (const gchar *device, GError **error) {
+static gchar* bd_nvdimm_namespace_get_devname_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_nvdimm_namespace_get_devname' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_get_devname' called, but not implemented!");
@@ -157,7 +157,7 @@ gchar* bd_nvdimm_namespace_get_devname (const gchar *device, GError **error) {
 }
 
 
-static gboolean  bd_nvdimm_namespace_enable_stub (const gchar *namespace, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_nvdimm_namespace_enable_stub (const gchar *namespace G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_nvdimm_namespace_enable' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_enable' called, but not implemented!");
@@ -181,7 +181,7 @@ gboolean  bd_nvdimm_namespace_enable (const gchar *namespace, const BDExtraArg *
 }
 
 
-static gboolean  bd_nvdimm_namespace_disable_stub (const gchar *namespace, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_nvdimm_namespace_disable_stub (const gchar *namespace G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_nvdimm_namespace_disable' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_disable' called, but not implemented!");
@@ -205,7 +205,7 @@ gboolean  bd_nvdimm_namespace_disable (const gchar *namespace, const BDExtraArg
 }
 
 
-static BDNVDIMMNamespaceInfo* bd_nvdimm_namespace_info_stub (const gchar *namespace, const BDExtraArg **extra, GError **error) {
+static BDNVDIMMNamespaceInfo* bd_nvdimm_namespace_info_stub (const gchar *namespace G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_nvdimm_namespace_info' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_info' called, but not implemented!");
@@ -230,7 +230,7 @@ BDNVDIMMNamespaceInfo* bd_nvdimm_namespace_info (const gchar *namespace, const B
 }
 
 
-static BDNVDIMMNamespaceInfo** bd_nvdimm_list_namespaces_stub (const gchar *bus, const gchar *region, gboolean idle, const BDExtraArg **extra, GError **error) {
+static BDNVDIMMNamespaceInfo** bd_nvdimm_list_namespaces_stub (const gchar *bus G_GNUC_UNUSED, const gchar *region G_GNUC_UNUSED, gboolean idle G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_nvdimm_list_namespaces' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_list_namespaces' called, but not implemented!");
@@ -260,7 +260,7 @@ BDNVDIMMNamespaceInfo** bd_nvdimm_list_namespaces (const gchar *bus, const gchar
 }
 
 
-static gboolean  bd_nvdimm_namespace_reconfigure_stub (const gchar* namespace, BDNVDIMMNamespaceMode mode, gboolean force, const BDExtraArg **extra, GError** error) {
+static gboolean  bd_nvdimm_namespace_reconfigure_stub (const gchar* namespace G_GNUC_UNUSED, BDNVDIMMNamespaceMode mode G_GNUC_UNUSED, gboolean force G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError** error) {
     g_critical ("The function 'bd_nvdimm_namespace_reconfigure' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_reconfigure' called, but not implemented!");
@@ -285,7 +285,7 @@ gboolean  bd_nvdimm_namespace_reconfigure (const gchar* namespace, BDNVDIMMNames
 }
 
 
-static const guint64 * bd_nvdimm_namespace_get_supported_sector_sizes_stub (BDNVDIMMNamespaceMode mode, GError **error) {
+static const guint64 * bd_nvdimm_namespace_get_supported_sector_sizes_stub (BDNVDIMMNamespaceMode mode G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_nvdimm_namespace_get_supported_sector_sizes' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_get_supported_sector_sizes' called, but not implemented!");
