@@ -1,14 +1,13 @@
 import json
-import os
 import re
+import shutil
 import unittest
 import overrides_hack
 
-from distutils.version import LooseVersion
+from packaging.version import Version
 
 from utils import run_command, read_file, fake_path, TestTags, tag_test
 from gi.repository import BlockDev, GLib
-from distutils.spawn import find_executable
 
 
 class NVDIMMTestCase(unittest.TestCase):
@@ -17,8 +16,8 @@ class NVDIMMTestCase(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        if not find_executable("ndctl"):
-            raise unittest.SkipTest("ndctl executable not foundin $PATH, skipping.")
+        if not shutil.which("ndctl"):
+            raise unittest.SkipTest("ndctl executable not found in $PATH, skipping.")
 
         if not BlockDev.is_initialized():
             BlockDev.init(cls.requested_plugins, None)
@@ -43,7 +42,7 @@ class NVDIMMNamespaceTestCase(NVDIMMTestCase):
         m = re.search(r"([\d\.]+)", out)
         if not m or len(m.groups()) != 1:
             raise RuntimeError("Failed to determine ndctl version from: %s" % out)
-        return LooseVersion(m.groups()[0])
+        return Version(m.groups()[0])
 
     def setUp(self):
         self.sys_info = self._get_nvdimm_info()
@@ -53,9 +52,12 @@ class NVDIMMNamespaceTestCase(NVDIMMTestCase):
         # skip the test if there is more than one device
         # these tests change nvdimm mode a we need to be sure that we are really
         # working with the 'fake' device created by the memmap kernel cmdline option
-        if type(self.sys_info) is not dict:
+        if len(self.sys_info) > 1:
             self.skipTest("Multiple NVDIMM devices found.")
 
+        # get the dict for the first nvdimm device
+        self.sys_info = self.sys_info[0]
+
         # skip the tests if the nvdimm is a 'fake' one
         cmdline = read_file("/proc/cmdline")
         if "memmap=" not in cmdline:
@@ -109,7 +111,7 @@ class NVDIMMNamespaceTestCase(NVDIMMTestCase):
 
     @tag_test(TestTags.EXTRADEPS, TestTags.UNSAFE)
     def test_enable_disable(self):
-        # non-existing/unknow namespace
+        # non-existing/unknown namespace
         with self.assertRaises(GLib.GError):
             BlockDev.nvdimm_namespace_enable("definitely-not-a-namespace")
 
@@ -142,13 +144,13 @@ class NVDIMMNamespaceTestCase(NVDIMMTestCase):
                                                   BlockDev.NVDIMMNamespaceMode.SECTOR,
                                                   False)
 
-        # non-existing/unknow mode
+        # non-existing/unknown mode
         with self.assertRaises(GLib.GError):
             BlockDev.nvdimm_namespace_reconfigure(self.sys_info["dev"],
                                                   BlockDev.NVDIMMNamespaceMode.UNKNOWN,
                                                   True)
 
-        # non-existing/unknow namespace
+        # non-existing/unknown namespace
         with self.assertRaises(GLib.GError):
             BlockDev.nvdimm_namespace_reconfigure("definitely-not-a-namespace",
                                                   BlockDev.NVDIMMNamespaceMode.SECTOR,
@@ -165,7 +167,7 @@ class NVDIMMNamespaceTestCase(NVDIMMTestCase):
         # ndctl renamed the modes from 'memory' and 'dax' to 'fsdax' and 'devdax'
         # in version 60, so we need to choose different mode based on version
         ndctl_version = self._get_ndctl_version()
-        if ndctl_version >= LooseVersion("60.0"):
+        if ndctl_version >= Version("60.0"):
             mode = BlockDev.NVDIMMNamespaceMode.FSDAX
         else:
             mode = BlockDev.NVDIMMNamespaceMode.MEMORY
@@ -185,42 +187,36 @@ class NVDIMMNamespaceTestCase(NVDIMMTestCase):
         self.assertEqual(info.mode, BlockDev.NVDIMMNamespaceMode.SECTOR)
 
 
-class NVDIMMUnloadTest(NVDIMMTestCase):
-    def setUp(self):
-        # make sure the library is initialized with all plugins loaded for other
-        # tests
-        self.addCleanup(BlockDev.reinit, self.requested_plugins, True, None)
-
+class NVDIMMDepsTest(NVDIMMTestCase):
     @tag_test(TestTags.NOSTORAGE)
-    def test_check_no_ndctl(self):
-        """Verify that checking ndctl tool availability works as expected"""
-
-        # unload all plugins first
-        self.assertTrue(BlockDev.reinit([], True, None))
+    def test_missing_dependencies(self):
+        """Verify that checking for technology support works as expected"""
 
         with fake_path(all_but="ndctl"):
-            # no ndctl tool available, the NVDIMM plugin should fail to load
-            with self.assertRaises(GLib.GError):
-                BlockDev.reinit(self.requested_plugins, True, None)
+            # no ndctl tool available
+            with self.assertRaisesRegex(GLib.GError, "The 'ndctl' utility is not available"):
+                BlockDev.nvdimm_is_tech_avail(BlockDev.NVDIMMTech.NAMESPACE, BlockDev.NVDIMMTechMode.RECONFIGURE)
 
-            self.assertNotIn("nvdimm", BlockDev.get_available_plugin_names())
-
-        # load the plugins back
-        self.assertTrue(BlockDev.reinit(self.requested_plugins, True, None))
-        self.assertIn("nvdimm", BlockDev.get_available_plugin_names())
+            # ndctl is needed only for reconfigure
+            avail = BlockDev.nvdimm_is_tech_avail(BlockDev.NVDIMMTech.NAMESPACE, BlockDev.NVDIMMTechMode.CREATE)
+            self.assertTrue(avail)
 
 
 class NVDIMMNoDevTest(NVDIMMTestCase):
 
+    @tag_test(TestTags.NOSTORAGE)
+    def test_plugin_version(self):
+       self.assertEqual(BlockDev.get_plugin_soname(BlockDev.Plugin.NVDIMM), "libbd_nvdimm.so.3")
+
     @tag_test(TestTags.NOSTORAGE)
     def test_supported_sector_sizes(self):
         """Verify that getting supported sector sizes works as expected"""
 
         with self.assertRaises(GLib.GError):
-            BlockDev.nvdimm_namepace_get_supported_sector_sizes(BlockDev.NVDIMMNamespaceMode.UNKNOWN)
+            BlockDev.nvdimm_namespace_get_supported_sector_sizes(BlockDev.NVDIMMNamespaceMode.UNKNOWN)
 
-        sizes = BlockDev.nvdimm_namepace_get_supported_sector_sizes(BlockDev.NVDIMMNamespaceMode.SECTOR)
+        sizes = BlockDev.nvdimm_namespace_get_supported_sector_sizes(BlockDev.NVDIMMNamespaceMode.SECTOR)
         self.assertListEqual(sizes, [512, 520, 528, 4096, 4104, 4160, 4224])
 
-        sizes = BlockDev.nvdimm_namepace_get_supported_sector_sizes(BlockDev.NVDIMMNamespaceMode.FSDAX)
+        sizes = BlockDev.nvdimm_namespace_get_supported_sector_sizes(BlockDev.NVDIMMNamespaceMode.FSDAX)
         self.assertListEqual(sizes, [512, 4096])
